Extension traits, process adapters, and extension command helpers. Extension interfaces for package registry integrations.
Extensions implement crate::extension::Extension to report supported
registries, discover dependency metadata, and return package artifact
metadata. Extensions can be compiled into a client with
crate::extension::FromLib or invoked through a process with
crate::extension::ProcessExtension.
Process-backed extension binaries should call
crate::extension::run_command from their main function to expose the
standard Thirdpass extension subcommands.
Structs
- Dependency
- A dependency as specified within a dependencies definition file.
- File
Defined Dependencies - A dependencies specification file found from inspecting the local filesystem.
- Package
Dependencies - Package dependencies found by querying a registry.
- Process
Extension - Extension adapter that communicates with an extension executable.
- Registry
Package Metadata - Metadata returned by an extension for a package in a registry.
- Review
Target Policy - Policy for selecting automatic review target files.
- Version
Error - Error value used when an extension cannot resolve a dependency version.
Traits
- Dependencies
Collection - Common view over dependency collections returned by extensions.
- Extension
- Registry and dependency behavior implemented by every Thirdpass extension.
- FromLib
- Extension implementation that is compiled directly into the current process.
- From
Process - Extension implementation that is loaded by invoking a process.
Functions
- run_
command - Run the standard process-extension command line interface for an extension.
Type Aliases
- Version
Parse Result - Parsed dependency version or a version parsing error.