pub struct VersionError(/* private fields */);Expand description
Error value used when an extension cannot resolve a dependency version.
Implementations
Sourceimpl VersionError
impl VersionError
Sourcepub fn from_missing_version() -> Self
pub fn from_missing_version() -> Self
Build an error for dependency metadata that omits a version.
Sourcepub fn from_parse_error(raw_version_number: &str) -> Self
pub fn from_parse_error(raw_version_number: &str) -> Self
Build an error for a dependency version string that could not be parsed.