pub struct PackageManifestFile {
pub path: String,
pub size_bytes: u64,
}Expand description
Metadata for a regular file in a package archive.
Fields
path: StringPath of the file relative to the package root.
size_bytes: u64Size of the file contents in bytes.