pub struct ReviewFile {
pub file_path: String,
pub file_hash: Option<FileHash>,
pub summary: Option<String>,
pub security_summary: Option<SecuritySummary>,
pub confidence: Option<ReviewConfidence>,
pub comments: Vec<ReviewComment>,
}Expand description
Review output for a single package-relative file.
Fields
file_path: StringPath of the reviewed file relative to the package root.
file_hash: Option<FileHash>Content hash for the reviewed file, when the client can compute it.
summary: Option<String>Agent-written summary for this individual file review.
security_summary: Option<SecuritySummary>Security severity for this individual file review.
confidence: Option<ReviewConfidence>Agent confidence for this individual file review.
comments: Vec<ReviewComment>Specific comments reported for the reviewed file.